@@ -1,6 +1,6 @@
 # $Author: ddumont $
-# $Date: 2009-03-12 13:33:03 +0100 (Thu, 12 Mar 2009) $
-# $Revision: 893 $
+# $Date: 2010-02-18 18:29:48 +0100 (Thu, 18 Feb 2010) $
+# $Revision: 1086 $
 
 #    Copyright (c) 2008 Dominique Dumont.
 #
@@ -30,7 +30,7 @@ use base qw/Tk::Frame Config::Model::Tk::AnyViewer/;
 use vars qw/$VERSION/ ;
 use subs qw/menu_struct/ ;
 
-$VERSION = sprintf "1.%04d", q$Revision: 893 $ =~ /(\d+)/;
+$VERSION = sprintf "1.%04d", q$Revision: 1086 $ =~ /(\d+)/;
 
 Construct Tk::Widget 'ConfigModelHashViewer';
 
@@ -70,9 +70,7 @@ sub Populate {
     }
 
     $cw->add_info($cw) ;
-    $cw->add_help_frame() ;
-    $cw->add_help(class   => $hash->parent->get_help) ;
-    $cw->add_help(element => $hash->parent->get_help($hash->element_name)) ;
+    $cw->add_summary_and_description($hash) ;
     $cw->add_editor_button($path) ;
 
     $cw->SUPER::Populate($args) ;
@@ -95,7 +93,7 @@ sub add_info {
 	push @items, "cargo class: " . $hash->config_class_name ;
     }
 
-    foreach my $what (qw/min max max_nb/) {
+    foreach my $what (qw/min_index max_index max_nb/) {
 	my $v = $hash->$what() ;
 	my $str = $what ;
 	$str =~ s/_/ /g;
