@@ -1,6 +1,6 @@
 # $Author: ddumont $
-# $Date: 2009-06-23 13:41:22 +0200 (Tue, 23 Jun 2009) $
-# $Revision: 979 $
+# $Date: 2010-01-29 14:22:45 +0100 (Fri, 29 Jan 2010) $
+# $Revision: 1061 $
 
 #    Copyright (c) 2008 Dominique Dumont.
 #
@@ -30,7 +30,7 @@ use Log::Log4perl ;
 use base qw/Tk::Frame Config::Model::Tk::AnyViewer/;
 use vars qw/$VERSION/ ;
 
-$VERSION = sprintf "1.%04d", q$Revision: 979 $ =~ /(\d+)/;
+$VERSION = sprintf "1.%04d", q$Revision: 1061 $ =~ /(\d+)/;
 
 Construct Tk::Widget 'ConfigModelLeafViewer';
 
@@ -67,8 +67,7 @@ sub Populate {
     $cw->add_header(View => $leaf) ;
 
     my @pack_args = @fx ;
-    @pack_args = @fbe1 if $vt eq 'string' or $vt eq 'enum' 
-                       or $vt eq 'reference' ;
+    @pack_args = @fbe1 if $vt eq 'string' ;
     my $lv_frame = $cw->Frame(qw/-relief raised -borderwidth 2/)
       ->pack(@pack_args) ;
     $lv_frame -> Label(-text => 'Value') -> pack() ;
@@ -80,7 +79,9 @@ sub Populate {
 					       -scrollbars => 'ow',
 					      )
 	  ->pack(@fbe1);
-	$cw->{e_widget}->insert('end',$v) ;
+	$cw->{e_widget}->insert('end',$v,'value') ;
+	$cw->{e_widget}
+	  ->tagConfigure(qw/value -lmargin1 2 -lmargin2 2 -rmargin 2/);
     }
     else {
 	my $v_frame = $lv_frame->Frame(qw/-relief sunken -borderwidth 1/)
